@@ -10,6 +10,7 @@ from .v3.domains import Domains
 from .v3.data_model import DataModel
 from .v3.device_monitoring import DeviceMonitoring
 from .v3.lifecycle_management import LifecycleManagement
+from .v3.resources import Resources
 from .v3.sessions import Sessions
 from .v3.setting_values import SettingValues
 from .v3.task_templates import TaskTemplates
@@ -49,6 +50,7 @@ class Coiote:
         self.dialects: Dialects = self._make_module(Dialects)
         self.domains: Domains = self._make_module(Domains)
         self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
+        self.resources: Resources = self._make_module(Resources)
         self.sessions: Sessions = self._make_module(Sessions)
         self.setting_values: SettingValues = self._make_module(SettingValues)
         self.task_reports: TaskReports = self._make_module(TaskReports)
